////////////////////////////////////////////////////////////////////////////////
//
// Fracter - A simple Mandelbrot Set viewer.
//
// Copyright (C) 2010 Sarah Eris Horsley Caffee
//
// This file is part of Fracter.
//
// Fracter is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//
// Julia.h
// Julia set calculator class definition
//
////////////////////////////////////////////////////////////////////////////////

#ifndef JULIA_H
#define JULIA_H

#include <iostream>

#include <string>

#include "Fractal.h"

////////////////////////////////////////////////////////////////////////////////
class ViewJulia : public View
   {
   public:
   ViewJulia(std::string t, 
	     double re, double im, double s, 
	     unsigned int max,
	     double kr, double ki);

   private:
   friend class Julia;

   double k_re;
   double k_im;

   };

////////////////////////////////////////////////////////////////////////////////
class Julia : public Fractal
   {
   public:
   Julia();

   bool calc_set();

   bool get_option(std::string option, void * value) const;
   bool set_option(std::string option, void * value);
   ViewJulia * save_view();
   void restore_view(View * v);

   private:

   void set_display_name();

   double k_re;
   double k_im;

   };

////////////////////////////////////////////////////////////////////////////////
namespace
   {
   class JuliaFactory : public FractalFactory
      {
      public:
      JuliaFactory()
	 {
	 get_Fractal_map()[typeid(Julia).name()]=this;
	 }

      Fractal * create() const
	 {
	 return new Julia;
	 }
      } the_Julia_factory;
   }
#endif
